"""
Methods that controls the cykei client.
Controls communication and initializes the MainWindow.
"""

import json
import sys
import logging

from PySide2.QtWidgets import QApplication
from os.path import expanduser
from pkg_resources import require, DistributionNotFound

from cyckei.client.window import MainWindow


def main():
    """Initializes server and window"""

    try:
        version = require("cyckei")[0].version
    except DistributionNotFound:
        version = "(unpackaged)"

    print("Welcome to Cyckei Client version {}.".format(version))

    # Load configuration
    record_dir = expanduser("~") + "/cyckei"
    config = json.load(open(record_dir + "/config.json", "r"))
    config["path"] = record_dir

    # Start logging
    log_file = "{}/client.log".format(record_dir)
    logging.basicConfig(filename=log_file, level=config["verbosity"],
                        format='%(asctime)s %(message)s')
    logging.info("--- Client started.")

    app = QApplication(sys.argv)
    app.setStyle("fusion")
    window = MainWindow(config)
    window.show()

    sys.exit(app.exec_())


if __name__ == "__main__":
    main()



import logging

from pkg_resources import require, DistributionNotFound, resource_filename
from json import load
from os.path import expanduser, exists
from os import makedirs
from shutil import copy

from cyckei.server import server


def main():
    """
        This is the main entrypoint and routine of Cyckei Vayu.
        Vayu aims to make cyckei more efficient in many aspects.
    """
    print("\n")

    try:
        version = require("cyckei")[0].version
    except DistributionNotFound:
        version = "(unpackaged)"

    print("Welcome to Cyckei Server version {}.".format(version))

    # Setup recording direcory if unavailable
    print("Checking for recording directory...")
    record_dir = expanduser("~") + "/cyckei"
    file_structure(record_dir)

    # Load configuration
    print("Loading configuration...")
    config = load(open(record_dir + "/config.json", "r"))
    config["path"] = record_dir

    # Start logging
    log_file = "{}/server.log".format(record_dir)
    print("Starting log...")
    logging.basicConfig(filename=log_file, level=config["verbosity"],
                        format='%(asctime)s %(message)s')
    logging.info("--- Server started.")

    # Start server
    server.main(config)


def file_structure(path):
    """Checks for existing folder structure and sets up if missing"""

    if not exists(path):
        makedirs(path)
    if not exists(path + "/tests"):
        makedirs(path + "/tests")
    if not exists(path + "/config.json"):
        copy(resource_filename("cyckei.server", "res/default.config.json"),
             path + "/config.json")
    if not exists(path + "/batch.txt"):
        copy(resource_filename("cyckei.server", "res/batch.txt"),
             path + "/batch.txt")
    if not exists(path + "/scripts"):
        makedirs(path + "/scripts")
        copy(resource_filename("cyckei.server", "res/example-script"),
             path + "/scripts/example")


if __name__ == "__main__":
    main()



from setuptools import setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="cyckei",
    version="0.1.dev7",
    author="Gabriel Ewig",
    author_email="gabriel@cyclikal.com",
    description="Keithley Battery Cycler for Python3",
    long_description=long_description,
    long_description_content_type="text/markdown",
    keywords="keithley battery lithium-ion cycling calorimetry",
    url="https://gitlab.com/cyclikal/cyckei",

    packages=["cyckei", "cyckei.server", "cyckei.client"],
    package_dir={
        "cyckei": "cyckei",
        "cyckei.server": "cyckei/server",
        "cyckei.client": "cyckei/client"
    },
    package_data={
        "cyckei.server": ["cyckei/server/res"],
        "cyckei.client": ["cyckei/client/res"],
    },
    include_package_data=True,

    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
        "Topic :: Scientific/Engineering",
    ],
    install_requires=[
        "zmq",
        "pyvisa",
        "PySide2",
    ],
    entry_points={
        "console_scripts": [
            "cyckei = cyckei.__main__:main",
            "cyckei-server = cyckei.server.__main__:main",
            "cyckei-client = cyckei.client.__main__:main"
        ],
    },
)
